import click
import subprocess as sp
import os

from app.helper import install_available


@click.group()
def host():
    pass


@host.command("setup")
@click.option("--path", required=True)
@click.option("--ssh_username", required=True)
@click.option("--ssh_key_path", required=True, help="For Example, ~/.ssh/id_rsa")
@click.option("--ssh_key_pass", required=True)
@click.option("--etcd_url", required=True)
@click.option("--without_ceph", default=False, type=bool)
@click.option("--branch", default="master")
def setup(path, ssh_username, ssh_key_path, ssh_key_pass, etcd_url, without_ceph, branch):
    os.chdir(path)

    repo_name = "ucloud-vm"
    
    # Clone main repo
    sp.check_output(['git', 'clone', '--single-branch', '--branch', branch,
                    f'https://code.ungleich.ch/ungleich-public/{repo_name}.git'])

    # Create .env file
    with open(os.path.join(repo_name, ".env"), "w") as f:
        content = (
            f"ssh_username={ssh_username}\n"
            f"ssh_pkey={ssh_key_path}\n"
            f"ssh_private_key_password={ssh_key_pass}\n"
            f"ETCD_URL={etcd_url}\n"
            f"WITHOUT_CEPH={without_ceph}\n",
            f"VM_PREFIX=/v1/vm/\n",
            f"HOST_PREFIX=/v1/host/\n",
            f"IMAGE_PREFIX=/v1/image/\n",
            f"IMAGE_STORE_PREFIX=/v1/image_store/\n",
            f"REQUEST_PREFIX=/v1/request/\n",
            f"FILE_PREFIX=/v1/file/\n"
        )
        f.writelines(content)

    install_available(repo_name)
    
    # Create virtualenv with site-packages enabled and install all dependencies
    sp.check_output(['pipenv', 'install'], cwd=repo_name)