import click
import subprocess as sp
import os
import shutil

from app.helper import clone_common, clone_etcd_wrapper, install_available


@click.group()
def scheduler():
    pass


@scheduler.command("setup")
@click.option("--path", required=True)
@click.option("--vm_prefix", required=True)
@click.option("--host_prefix", required=True)
@click.option("--request_prefix", required=True)
@click.option("--etcd_url", required=True)
@click.option("--branch", default="master")
def setup(path, vm_prefix, host_prefix, request_prefix, etcd_url, branch):
    os.chdir(path)

    repo_name = "ucloud-scheduler"

    # Clone main repo
    sp.check_output(['git', 'clone', '--single-branch', '--branch', branch,
                    f'https://code.ungleich.ch/ungleich-public/{repo_name}.git'])

    # Create .env file
    with open(os.path.join(repo_name, ".env"), "w") as f:
        content = (
            f"VM_PREFIX={vm_prefix}\n"
            f"HOST_PREFIX={host_prefix}\n"
            f"REQUEST_PREFIX={request_prefix}\n"
            f"ETCD_URL={etcd_url}\n",
            f"VM_PREFIX=/v1/vm/\n",
            f"HOST_PREFIX=/v1/host/\n",
            f"IMAGE_PREFIX=/v1/image/\n",
            f"IMAGE_STORE_PREFIX=/v1/image_store/\n",
            f"REQUEST_PREFIX=/v1/request/\n",
            f"FILE_PREFIX=/v1/file/\n"
        )
        f.writelines(content)

    
    install_available(repo_name)
    
    # Create virtualenv with site-packages enabled and install all dependencies
    sp.check_output(['pipenv', 'install'], cwd=repo_name)